.. highlight:: shell

============
Installation
============


Stable release
--------------

To install dockersh, run this command in your terminal:

.. code-block:: console

    $ pipx install dockersh

This is the preferred method to install dockersh, as it will always install the most recent stable release.

If you don't have `pipx`_ installed, this `PIPX installation guide`_ can guide
you through the process.

.. _pipx: https://pipx.pypa.io/pipx
.. _PIPX installation guide: https://pypa.github.io/pipx/installation/


From sources
------------

The sources for dockersh can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/solamarpreet/dockersh

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/solamarpreet/dockersh/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/solamarpreet/dockersh
.. _tarball: https://github.com/solamarpreet/dockersh/tarball/master
